@@ -317,6 +317,31 @@ test_expect_success '--tag-rename' '
 	)
 '
 
+test_expect_success 'tag of tag before relevant portion of history' '
+	test_create_repo filtered_tag_of_tag &&
+	(
+		cd filtered_tag_of_tag &&
+		echo contents >file &&
+		git add file &&
+		git commit -m "Initial" &&
+
+		git tag -a -m "Inner Tag" inner_tag HEAD &&
+		git tag -a -m "Outer Tag" outer_tag inner_tag &&
+
+		mkdir subdir &&
+		echo stuff >subdir/whatever &&
+		git add subdir &&
+		git commit -m "Add file in subdir" &&
+
+		git filter-repo --force --subdirectory-filter subdir &&
+
+		git show-ref >refs &&
+		! grep refs/tags refs &&
+		git log --all --oneline >commits &&
+		test_line_count = 1 commits
+	)
+'
+
 test_expect_success '--subdirectory-filter' '
 	setup_metasyntactic_repo &&
 	(
@@ -1649,4 +1674,37 @@ test_expect_success '--version' '
 	test_cmp expect actual
 '
 
+test_expect_success 'empty author ident' '
+	test_create_repo empty_author_ident &&
+	(
+		cd empty_author_ident &&
+
+		git init &&
+		cat <<-EOF | git fast-import --quiet &&
+			feature done
+			blob
+			mark :1
+			data 8
+			initial
+
+			reset refs/heads/develop
+			commit refs/heads/develop
+			mark :2
+			author <empty@ident.ity> 1535228562 -0700
+			committer Full Name <email@add.ress> 1535228562 -0700
+			data 8
+			Initial
+			M 100644 :1 filename
+
+			done
+			EOF
+
+		git filter-repo --force --path-rename filename:stuff &&
+
+		git log --format=%an develop >actual &&
+		echo >expect &&
+		test_cmp expect actual
+	)
+'
+
 test_done
